@@ -5,6 +5,6 @@ set dir=`dirname $0`
 
 setenv LD_LIBRARY_PATH ${dir}:${dir}/../../CCS/solaris
 setenv MSPCCS_DATA ${dir}/../../data
-setenv JAVA_HOME /usr/jdk1.5.0_18
+setenv JAVA_HOME /usr/jdk1.6.0_35
 
-${JAVA_HOME}/bin/java -Xss1024k -jar ${dir}/MSPCCS.jar
+${JAVA_HOME}/bin/java -Xss1024k -jar ${dir}/MSPCCS.jar >& /dev/null
